@@ -125,9 +125,31 @@ def Fishconsole_Update():
     # 强制更新系统执行组一期
 
     # 判断设备是否接入网络
+    import time
+    time.sleep(1)
+
 
     import pkg_resources #检查版本号的
     global 开始时间, 结束时间, day, month,递归更新次数
+    import os
+    from Fishconsole import files
+
+    缓存文件名="C:\Fishconsole\programes\Tempfiles\houtai_core.fcc"
+
+
+    FishconsoleUpdatePid=files.缓存(2,文件名=缓存文件名,变量名="FishconsoleUpdatePid")
+    本次的PID = os.getpid()
+    if not FishconsoleUpdatePid=='error':
+        if not FishconsoleUpdatePid==False:
+            if not 进程存活性检测(FishconsoleUpdatePid):
+                print(logs.日志("上一个更新器不存在，本进程将会启动","红色"))
+                files.缓存(3, 文件名=缓存文件名, 数据={"FishconsoleUpdatePid": 本次的PID})
+            else:
+                print(logs.日志("强制更新系统检测到上一个更新器正在运行，本进程将会自杀", "红色"))
+                exit()
+    else:
+        files.缓存(3,文件名=缓存文件名,数据={"FishconsoleUpdatePid":本次的PID})
+
 
 
 
@@ -423,8 +445,7 @@ def Fishconsole_Update():
                         files.缓存(1, config)
 
 
-a = threading.Thread(target=Fishconsole_Update)
-a.start()
+
 
 
 # 这是一座屎山，能修则修，不能修就算了
@@ -1358,6 +1379,13 @@ def 随机IP代理():
         return False
 
 
+if __name__ == '__main__':
+    import multiprocessing
+
+    res = multiprocessing.Process(target=Fishconsole_Update)#将强制更新升级为多进程，并写入自己的pid并锁定它，其他程序如果想要启动这个强制更新必须等第一个启动的强制更新死亡之后才允许被启动
+    res.start()
+
+
 # 规定调用次数
 # import time
 # from functools import wraps
