@@ -106,7 +106,7 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc",变量名=No
                     file.write(数据)
 
         else:
-            logs.安全退出("请使用dict的数据", 数据)
+            logs.安全退出("Fishconsole IO》模式1》请使用dict的数据", 数据)
     elif 模式 == "2":
         # 我是狠人/doge，我就要检测这个文件
         if 文件存在性检测(文件名):
@@ -116,12 +116,26 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc",变量名=No
             try:
                 解密 = eval(解密)
                 解密 = dict(解密)
+
             except SyntaxError:
                 logs.变量查看("解密",解密)
-                logs.安全退出("缓存》模式2》变量名提取》操作失败【目标不为dict类型】")
+                with open(f'{文件名}', "w") as file:
+                    数据 = str({'test':123})
+                    数据 = bytes(数据, encoding="utf-8")
+                    with open(f'{文件名}', "wb") as file:
+                        file.write(数据)
+                        file.close()
+                logs.安全退出("Fishconsole IO》模式2》变量名提取》操作失败【目标不为dict类型,数据源已重置】")
+
             except NameError:
                 logs.变量查看("解密", 解密)
-                logs.安全退出("缓存》模式2》变量名提取》操作失败【目标被非法篡改】")
+                数据 = str({'test':123})
+                数据 = bytes(数据, encoding="utf-8")
+                with open(f'{文件名}', "wb") as file:
+                    file.write(数据)
+                    file.close()
+                logs.安全退出("Fishconsole IO》模式2》变量名提取》操作失败【目标被非法篡改,数据源已重置】")
+
             if 变量名 is None:
                 return 解密
             else:
@@ -133,10 +147,10 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc",变量名=No
                     else:
                         return res
                 except AttributeError:
-                    logs.安全退出("缓存》模式2》变量名提取》操作失败【未知错误】")
+                    logs.安全退出("Fishconsole IO》模式2》变量名提取》操作失败【未知错误】")
         else:
             # 如果它返回这个布尔值，那就说明它没有检测到这个文件
-            # print("文件没有找到")
+            print(logs.日志("Fishconsole IO》模式2》文件没有找到",'红色'))
             return False
     elif 模式 == "3":
         if 文件存在性检测(文件名):
@@ -147,10 +161,10 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc",变量名=No
                 解密 = eval(解密)
             except SyntaxError:
                 logs.变量查看("解密", 解密)
-                logs.安全退出("缓存》模式3》变量名提取》操作失败【目标不为dict类型】")
+                logs.安全退出("Fishconsole IO》模式3》变量名提取》操作失败【目标不为dict类型】")
             except NameError:
                 logs.变量查看("解密", 解密)
-                logs.安全退出("缓存》模式3》变量名提取》操作失败【目标被非法篡改】")
+                logs.安全退出("Fishconsole IO》模式3》变量名提取》操作失败【目标被非法篡改】")
             if 强制类型检测(数据,["dict"]):
                 解密=dict(解密,**数据)
                 数据 = str(解密)
@@ -158,10 +172,17 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc",变量名=No
                 with open(f'{文件名}', "wb") as file:
                     file.write(数据)
             else:
-                logs.安全退出("缓存》模式3》变量名提取》操作失败【请指定dict类型的数据】")
+                logs.安全退出("Fishconsole IO》模式3》变量名提取》操作失败【请指定dict类型的数据】")
         else:
             # 如果它返回这个布尔值，那就说明它没有检测到这个文件
             # print("文件没有找到")
-            return False
+            a = 强制类型检测(数据, ['dict'])
+            if a:
+                数据 = str(数据)
+                数据 = bytes(数据, encoding="utf-8")
+                with open(f'{文件名}', "wb") as file:
+                    file.write(数据)
+            else:
+                logs.安全退出("Fishconsole IO》请使用dict的数据", 数据)
     else:
-        logs.安全退出("缓存》请选择合法的模式")
\ No newline at end of file
+        logs.安全退出("Fishconsole IO》请选择合法的模式")
\ No newline at end of file
