@@ -32,8 +32,6 @@ def 颜色(text, 色选="None"):
     :param 色选: 你要加的颜色，现在的可选颜色是：紫色，红色，黄色，蓝色，青色，绿色和相对应的背景色
     :return: 格式化后的内容
     """
-    import colorama
-    colorama.init(autoreset=True)#针对其他控制台的补丁
 
     if 色选 == "紫色":
         return f"\033[35m{text}\033[0m"
@@ -78,6 +76,7 @@ def 输入(text, 色选="红色"):
     :return: 用户输入的值
     """
     a="\033[1m" + "○"
+
     res = input(f"{颜色(a, f'{色选}')} 》{text}  {颜色('||》', 色选)}")
     return res
 
