@@ -26,7 +26,7 @@ def 弹窗(显示文字, 标题, 确认显示文字):
 
 # noinspection PyStatementEffect
 def 选择对话框(显示文字, 标题, 选项: list, 图片地址: str = None):
-    a = files.强制类型检测(选项, "list")
+    a = files.强制类型检测(选项, ["list"])
     if a:
         1 + 1
     else:
@@ -39,7 +39,7 @@ def 选择对话框(显示文字, 标题, 选项: list, 图片地址: str = None
 
 # noinspection PyStatementEffect
 def 列表选择对话框(显示文字, 标题, 选项: list):
-    a = files.强制类型检测(选项, "list")
+    a = files.强制类型检测(选项, ["list"])
     if a:
         1 + 1
     else:
